@@ -14,6 +14,7 @@ use File::Copy qw( copy move );
 use File::Find qw( find );
 use Config;
 use Env qw( @PATH );
+use Fcntl;
 
 unshift @PATH, curdir();
 
@@ -28,27 +29,25 @@ locations.
 
 =cut
 
-my $is_distro_not_devel = -e 'charmonizer';
+my $is_distro_not_devel = -e 'c_src';
 my $base_dir = $is_distro_not_devel ? curdir() : updir();
 
-my $METAQUOTE_EXE_PATH     = 'metaquote' . $Config{_exe};
 my $CHARMONIZE_EXE_PATH    = 'charmonize' . $Config{_exe};
-my $CHARMONIZER_SOURCE_DIR = catdir( $base_dir, 'charmonizer', 'src' );
-my $FILTERED_DIR = catdir( $base_dir, qw( charmonizer filtered_src ) );
-my $C_SOURCE_DIR = catdir( $base_dir, 'c_src' );
-my $R_SOURCE_DIR = catdir( $C_SOURCE_DIR, 'r' );
+my $CHARMONIZER_SOURCE_DIR = 'charmonizer';
+my $C_SOURCE_DIR           = catdir( $base_dir, 'c_src' );
+my $R_SOURCE_DIR           = catdir( $C_SOURCE_DIR, 'r' );
 
 my $EXTRA_CCFLAGS = '';
-if ( $ENV{LUCY_DEBUG} || $ENV{KINO_DEBUG} ) {
-    require version;
+if ( defined $ENV{LUCY_DEBUG} || defined $ENV{KINO_DEBUG} ) {
+    $EXTRA_CCFLAGS .= "-DKINO_DEBUG ";
     if ( defined $Config{gccversion} ) {
-        $Config{gccversion} =~ /^([\d\.]+)/ or die "no match";
-        my $gcc_version = version->new("$1")->numify;
-        $EXTRA_CCFLAGS = "-DPERL_GCC_PEDANTIC -ansi -pedantic -Wall "
+        $Config{gccversion} =~ /^(\d+(\.\d+)?)/ or die "no match";
+        my $gcc_version = $1;
+        $EXTRA_CCFLAGS .= "-DPERL_GCC_PEDANTIC -ansi -pedantic -Wall "
             . "-std=c89 -Wno-long-long ";
         $EXTRA_CCFLAGS .= "-Wextra " if $gcc_version >= 3.4;    # correct
         $EXTRA_CCFLAGS .= "-Wno-variadic-macros "
-            if $gcc_version > 3.2;    # at least not on gcc 3.2
+            if $gcc_version > 3.4;    # at least not on gcc 3.4
     }
 }
 my $VALGRIND = $ENV{CHARM_VALGRIND} ? "valgrind --leak-check=full " : "";
@@ -76,46 +75,29 @@ sub use_kinosearch_mode {
     $kino_or_lucy = 'kino';
 }
 
-# Compile the metaquote source filter utility.
-sub ACTION_metaquote {
+# Collect all relevant Charmonizer files.  Can only be run during development.
+sub ACTION_charmgather {
     my $self = shift;
-    my $source_path
-        = catfile( $base_dir, qw( charmonizer metaquote_src metaquote.c ) );
-
-    # don't compile if we're up to date
-    return if $self->up_to_date( [$source_path], $METAQUOTE_EXE_PATH );
-
-    # compile
-    print "\nBuilding $METAQUOTE_EXE_PATH...\n\n";
-    my $cbuilder = ExtUtils::CBuilder->new;
-    my $o_file   = $cbuilder->compile(
-        source               => $source_path,
-        extra_compiler_flags => $EXTRA_CCFLAGS,
-    );
-    $cbuilder->link_executable(
-        objects  => [$o_file],
-        exe_file => $METAQUOTE_EXE_PATH,
-    );
-
-    # clean both the object file and the executable
-    $self->add_to_cleanup( $o_file, $METAQUOTE_EXE_PATH );
+    copy( "../charmonizer/charmonize.c", "charmonizer/charmonize.c" )
+        or die "Copy failed: $!";
+    copy( "../charmonizer/charm_test.c", "charmonizer/charm_test.c" )
+        or die "Copy failed: $!";
+    my $command
+        = "../charmonizer/bin/charmgather --src=../charmonizer/dev "
+        . "--in=charmonizer/charmonize.c --in=charmonizer/charm_test.c "
+        . "--out=charmonizer";
+    system($command);
 }
 
 # Build the charmonize executable.
 sub ACTION_charmonizer {
     my $self = shift;
 
-    $self->dispatch('metaquote');
-
-    # gather .charm and .harm files and run them through metaquote
-    if ( !-d $FILTERED_DIR ) {
-        mkpath($FILTERED_DIR) or die "can't mkpath '$FILTERED_DIR': $!";
-    }
-    my $charm_source_files = $self->_find_files( $CHARMONIZER_SOURCE_DIR,
-        sub { $File::Find::name =~ /\.c?harm$/ } );
-    my $filtered_files = $self->_metaquote_charm_files($charm_source_files);
-    my $charmonize_c   = catfile( $base_dir, qw( charmonizer charmonize.c ) );
-    my @all_source     = ( $charmonize_c, @$filtered_files );
+    # Gather .c and .h Charmonizer files.
+    my $charm_source_files = $self->rscan_dir( $CHARMONIZER_SOURCE_DIR,
+        qr/Charmonizer.+\.[ch]$/ );
+    my $charmonize_c = catfile( $base_dir, qw( charmonizer charmonize.c ) );
+    my @all_source = ( $charmonize_c, @$charm_source_files );
 
     # don't compile if we're up to date
     return if $self->up_to_date( \@all_source, $CHARMONIZE_EXE_PATH );
@@ -135,7 +117,7 @@ sub ACTION_charmonizer {
 
         $cbuilder->compile(
             source               => $_,
-            include_dirs         => [$FILTERED_DIR],
+            include_dirs         => [$CHARMONIZER_SOURCE_DIR],
             extra_compiler_flags => $EXTRA_CCFLAGS,
         );
     }
@@ -145,52 +127,7 @@ sub ACTION_charmonizer {
         exe_file => $CHARMONIZE_EXE_PATH,
     );
 
-    $self->add_to_cleanup( $FILTERED_DIR, @$filtered_files, @o_files,
-        $CHARMONIZE_EXE_PATH, );
-}
-
-sub _find_files {
-    my ( $self, $dir, $test_sub ) = @_;
-    my @files;
-    find(
-        {   wanted => sub {
-                if ( $test_sub->() and $File::Find::name !~ /\.\.?$/ ) {
-                    push @files, $File::Find::name;
-                }
-            },
-            no_chdir => 1,
-        },
-        $dir,
-    );
-    return \@files;
-}
-
-sub _metaquote_charm_files {
-    my ( $self, $charm_files ) = @_;
-    my @filtered_files;
-
-    for my $source_path (@$charm_files) {
-        my $dest_path = $source_path;
-        $dest_path =~ s#(.*)src#$1filtered_src#;
-        $dest_path =~ s#\.charm#.c#;
-        $dest_path =~ s#\.harm#.h#;
-
-        push @filtered_files, $dest_path;
-
-        next if ( $self->up_to_date( $source_path, $dest_path ) );
-
-        # create directories if need be
-        my ( undef, $dir, undef ) = splitpath($dest_path);
-        if ( !-d $dir ) {
-            $self->add_to_cleanup($dir);
-            mkpath $dir or die "Couldn't mkpath $dir";
-        }
-
-        # run the metaquote filter
-        system( $METAQUOTE_EXE_PATH, $source_path, $dest_path );
-    }
-
-    return \@filtered_files;
+    $self->add_to_cleanup( @o_files, $CHARMONIZE_EXE_PATH, );
 }
 
 # Run the charmonizer executable, creating the charmony.h file.
@@ -209,7 +146,8 @@ sub ACTION_charmony {
     my $flags     = "$Config{ccflags} $EXTRA_CCFLAGS";
     my $verbosity = $ENV{DEBUG_CHARM} ? 2 : 1;
     my $cc        = "$Config{cc}";
-    open( my $infile_fh, '>', $charmony_in )
+    unlink $charmony_in;
+    sysopen( my $infile_fh, $charmony_in, O_CREAT | O_WRONLY | O_EXCL )
         or die "Can't open '$charmony_in': $!";
     print $infile_fh qq|
         <charm_os_name>$os_name</charm_os_name>
@@ -235,22 +173,22 @@ sub ACTION_build_charm_test {
     $self->dispatch('charmony');
 
     # collect source files
-    my $source_path     = catfile( $base_dir, 'charmonizer', 'charm_test.c' );
-    my $exe_path        = "charm_test$Config{_exe}";
-    my $test_source_dir = catdir( $FILTERED_DIR, qw( Charmonizer Test ) );
-    my $source_files    = $self->_find_files( $FILTERED_DIR,
-        sub { $File::Find::name =~ m#Charmonizer/Test.*?\.c$# } );
+    my $source_path = catfile( $base_dir, 'charmonizer', 'charm_test.c' );
+    my $exe_path = "charm_test$Config{_exe}";
+    my $test_source_dir
+        = catdir( $CHARMONIZER_SOURCE_DIR, qw( Charmonizer Test ) );
+    my $source_files = $self->rscan_dir( $CHARMONIZER_SOURCE_DIR,
+        qr|Charmonizer/Test.*?\.c$| );
     push @$source_files, $source_path;
 
     # collect include dirs
-    my @include_dirs = ( $FILTERED_DIR, curdir() );
+    my @include_dirs = ( $CHARMONIZER_SOURCE_DIR, curdir() );
 
     # add Windows supplements
     if ( $Config{osname} =~ /mswin/i ) {
         my $win_compat_dir = catdir( $base_dir, 'c_src', 'compat' );
         push @include_dirs, $win_compat_dir;
-        my $win_compat_files = $self->_find_files( $win_compat_dir,
-            sub { $File::Find::name =~ m#\.c$# } );
+        my $win_compat_files = $self->rscan_dir( $win_compat_dir, qr|\.c$| );
         push @$source_files, @$win_compat_files;
     }
 
@@ -307,10 +245,8 @@ sub ACTION_dynamic_xs {
     }
 
     # build up a list of pound-include directives for all .h and .r files
-    my $h_files = $self->_find_files( $C_SOURCE_DIR,
-        sub { $File::Find::name =~ /\.h$/ } );
-    my $r_files = $self->_find_files( $R_SOURCE_DIR,
-        sub { $File::Find::name =~ /\.r$/ } );
+    my $h_files = $self->rscan_dir( $C_SOURCE_DIR, qr/\.h$/ );
+    my $r_files = $self->rscan_dir( $R_SOURCE_DIR, qr/\.r$/ );
 
     my $hr_includes = "";
     for ( @$h_files, @$r_files ) {
@@ -320,8 +256,7 @@ sub ACTION_dynamic_xs {
     }
 
     # concatenate all XS frags
-    my $pm_filepaths
-        = $self->_find_files( 'lib', sub { $File::Find::name =~ /\.pm$/ } );
+    my $pm_filepaths = $self->rscan_dir( 'lib', qr/\.pm$/ );
     my @pm_filepaths_with_xs;
     for my $pm_filepath (@$pm_filepaths) {
         open( my $pm_fh, '<', $pm_filepath )
@@ -351,7 +286,7 @@ sub ACTION_boilerplater {
         return;
     }
     else {
-        my $bp_path = catfile( $base_dir, 'devel', 'boilerplater.pl' );
+        my $bp_path = catfile( $base_dir, 'devel', 'bin', 'boilerplater.pl' );
         my $retval = system( 'perl', $bp_path, "--in=$C_SOURCE_DIR",
             "--out=$R_SOURCE_DIR", "--$kino_or_lucy" );
         $self->add_to_cleanup($R_SOURCE_DIR);
@@ -371,6 +306,27 @@ sub ACTION_code {
     $self->SUPER::ACTION_code;
 }
 
+# copied from Module::Build::Base.pm, added exclude '#' and follow symlinks
+sub rscan_dir {
+    my ( $self, $dir, $pattern ) = @_;
+    my @result;
+    local $_;    # find() can overwrite $_, so protect ourselves
+    my $subr
+        = !$pattern ? sub { push @result, $File::Find::name }
+        : !ref($pattern)
+        || ( ref $pattern eq 'Regexp' )
+        ? sub { push @result, $File::Find::name if /$pattern/ }
+        : ref($pattern) eq 'CODE'
+        ? sub { push @result, $File::Find::name if $pattern->() }
+        : die "Unknown pattern type";
+
+    File::Find::find( { wanted => $subr, no_chdir => 1, follow => 1 }, $dir );
+
+    # skip emacs lock files
+    my @filtered = grep !/#/, @result;
+    return \@filtered;
+}
+
 # Prepend a big fat warning to some content, then blast it out to a file.
 sub _write_autogenerated_file {
     my ( $self, $outfilepath, $source_path, $content ) = @_;
@@ -391,7 +347,8 @@ sub _write_autogenerated_file {
 END_AUTOGEN
 
     print "Writing $outfilepath\n";
-    open( my $fh, '>', $outfilepath )
+    unlink $outfilepath;
+    sysopen( my $fh, $outfilepath, O_CREAT | O_WRONLY | O_EXCL )
         or die "Couldn't open file '$outfilepath' for writing: $!";
     print $fh "$autogen_header\n$content"
         or die "Print to '$outfilepath' failed: $!";
@@ -411,18 +368,12 @@ autogenerate the file.
 sub ACTION_write_typemap {
     my $self = shift;
 
-    my $pm_filepaths
-        = $self->_find_files( 'lib', sub { $File::Find::name =~ /\.pm$/ } );
+    my $pm_filepaths = $self->rscan_dir( 'lib', qr/\.pm$/ );
     return
         if ( -e 'typemap' and $self->up_to_date( $pm_filepaths, 'typemap' ) );
 
     # build up a list of C-struct classes
-    my $h_filepaths = $self->_find_files(
-        $C_SOURCE_DIR,
-        sub {
-            $File::Find::name =~ /\.h$/;
-        }
-    );
+    my $h_filepaths = $self->rscan_dir( $C_SOURCE_DIR, qr/\.h$/ );
     my @struct_classes;
     for my $h_path (@$h_filepaths) {
         open( my $h_fh, '<', $h_path ) or die "Can't open '$h_path': $!";
@@ -462,7 +413,8 @@ END_OUTPUT
 
     # blast it out
     print "Writing typemap\n";
-    open( my $typemap_fh, '>', 'typemap' )
+    unlink 'typemap';
+    sysopen( my $typemap_fh, 'typemap', O_CREAT | O_WRONLY | O_EXCL )
         or die "Couldn't open 'typemap' for writing: $!";
     print $typemap_fh "$typemap_start $typemap_input $typemap_output"
         or die "Print to 'typemap' failed: $!";
@@ -531,7 +483,7 @@ VIEWBB_NOT_POINTER
         \$var.ptr = SvPV_nolen(\$arg);
         \$var.len = SvCUR(\$arg);
 
-VIEWBB_NOT_POINTER
+VIEWBB_NOT_POINTER_UTF8
         \$var._ = &${PREFIX}VIEWBYTEBUF;
         \$var.ptr = SvPVutf8_nolen(\$arg);
         \$var.len = SvCUR(\$arg);
@@ -580,7 +532,7 @@ sub ACTION_dist {
 
     $self->dispatch('boilerplater');
     print "Copying files...\n";
-    for my $dir (qw( charmonizer c_src devel )) {
+    for my $dir (qw( c_src devel )) {
         die "'$dir' already exists" if -e $dir;
         system("cp -R ../$dir $dir");
     }
@@ -596,7 +548,6 @@ sub ACTION_dist {
 
     # clean up and restore MANIFEST
     print "Removing copied files...\n";
-    rmtree('charmonizer');
     rmtree('c_src');
     rmtree('devel');
     print "Restoring MANIFEST...\n";
