@@ -5,7 +5,7 @@ package TestSchema;
 use base qw( KinoSearch::Schema );
 use KinoSearch::Analysis::Tokenizer;
 
-our %fields = ( content => 'KinoSearch::Schema::FieldSpec', );
+our %fields = ( content => 'text', );
 
 sub analyzer { KinoSearch::Analysis::Tokenizer->new }
 
