@@ -74,8 +74,7 @@ TokenBatch_append(TokenBatch *self, Token *token)
     }
 
     /* inlined VA_Push */
-    self->elems[ self->size ] = (Obj*)token;
-    REFCOUNT_INC(token);
+    self->elems[ self->size ] = (Obj*)REFCOUNT_INC(token);
     self->size++;
 }
 
@@ -116,8 +115,13 @@ TokenBatch_invert(TokenBatch *self)
 
     /* assign token positions */
     for ( ;tokens < limit; tokens++) {
-        (*tokens)->pos = token_pos;
-        token_pos += (*tokens)->pos_inc;
+        Token *const cur_token = *tokens;
+        cur_token->pos = token_pos;
+        token_pos += cur_token->pos_inc;
+        if (token_pos < cur_token->pos) {
+            CONFESS("Token positions out of order: %ld %ld", 
+                (long)cur_token->pos, (long)token_pos);
+        }
     }
 
     /* sort the tokens lexically, and hand off to cluster counting routine */
