@@ -38,10 +38,8 @@ DelDocs_new(InvIndex *invindex, SegInfo *seg_info)
     }
 
     /* assign */
-    REFCOUNT_INC(invindex);
-    REFCOUNT_INC(seg_info);
-    self->invindex  = invindex;
-    self->seg_info  = seg_info;
+    self->invindex  = REFCOUNT_INC(invindex);
+    self->seg_info  = REFCOUNT_INC(seg_info);
 
     /* read file if generation so indicates */
     if (self->del_gen)
