@@ -27,6 +27,13 @@ Lex_reset(Lexicon *self)
     ABSTRACT_DEATH(self, "Reset");
 }
 
+i32_t 
+Lex_get_size(Lexicon *self) 
+{
+    ABSTRACT_DEATH(self, "Get_Size");
+    UNREACHABLE_RETURN(i32_t);
+}
+
 i32_t 
 Lex_get_term_num(Lexicon *self) 
 {
@@ -51,6 +58,13 @@ Lex_build_sort_cache(Lexicon *self, struct kino_PostingList *plist,
     UNREACHABLE_RETURN(struct kino_IntMap*);
 }
 
+void
+Lex_seek_by_num(Lexicon *self, i32_t term_num)
+{
+    UNUSED_VAR(term_num);
+    ABSTRACT_DEATH(self, "Seek_By_Num");
+}
+
 /* Copyright 2006-2007 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
