@@ -50,16 +50,11 @@ PostWriter_new(InvIndex *invindex, SegInfo *seg_info,
     CREATE(self, PostingsWriter, POSTINGSWRITER);
 
     /* assign */
-    REFCOUNT_INC(invindex)
-    REFCOUNT_INC(seg_info);
-    REFCOUNT_INC(lex_writer);
-    if (pre_sorter != NULL)
-        REFCOUNT_INC(pre_sorter);
-    self->invindex      = invindex;
-    self->seg_info      = seg_info;
-    self->lex_writer    = lex_writer;
-    self->pre_sorter    = pre_sorter;
-    self->mem_thresh    = mem_thresh;
+    self->pre_sorter     = pre_sorter == NULL ? NULL : REFCOUNT_INC(pre_sorter);
+    self->invindex       = REFCOUNT_INC(invindex);
+    self->seg_info       = REFCOUNT_INC(seg_info);
+    self->lex_writer     = REFCOUNT_INC(lex_writer);
+    self->mem_thresh     = mem_thresh;
 
     /* derive */
     self->lex_tempname  =  BB_CLONE(seg_info->seg_name);
@@ -339,7 +334,7 @@ write_terms_and_postings(PostingsWriter *self, Obj *raw_post_source,
 static void
 finish_field(PostingsWriter *self, i32_t field_num)
 {
-    VArray *field_post_pools = (VArray*)VA_Fetch(self->post_pools, field_num);
+    VArray *field_post_pools = (VArray*)VA_Delete(self->post_pools, field_num);
     PostingPoolQueue *pool_q;
     IntMap      *pre_sort_remap = self->pre_sorter == NULL
                                     ? NULL
@@ -347,10 +342,11 @@ finish_field(PostingsWriter *self, i32_t field_num)
     
     if (field_post_pools == NULL)
         return;
-    else
-        /* TODO: can reusing mem_thresh double ram footprint? */
-        pool_q = PostPoolQ_new(field_post_pools, self->lex_instream,
-            self->post_instream, pre_sort_remap, self->mem_thresh); 
+
+    /* TODO: can reusing mem_thresh double ram footprint? */
+    pool_q = PostPoolQ_new(field_post_pools, self->lex_instream,
+        self->post_instream, pre_sort_remap, self->mem_thresh); 
+    REFCOUNT_DEC(field_post_pools);
 
     /* don't bother unless there's actually content */
     if (PostPoolQ_Peek(pool_q) != NULL) {
