@@ -76,7 +76,7 @@ PreSorter_add_seg_data(PreSorter *self, u32_t seg_max_doc,
 
     for (i = 0; i < seg_max_doc; i++) {
         i32_t new_doc_num = seg_doc_remap == NULL 
-            ? i 
+            ? (i32_t)i 
             : IntMap_Get(seg_doc_remap, i);
         if (new_doc_num != -1) {
             i32_t term_num = IntMap_Get(sort_cache, i);
