@@ -12,10 +12,8 @@ InvIndex_new(Schema *schema, Folder *folder)
     CREATE(self, InvIndex, INVINDEX);
 
     /* assign */
-    REFCOUNT_INC(schema);
-    REFCOUNT_INC(folder);
-    self->schema = schema;
-    self->folder = folder;
+    self->schema = REFCOUNT_INC(schema);
+    self->folder = REFCOUNT_INC(folder);
 
     return self;
 }
