@@ -16,10 +16,8 @@ MatchPostScorer_new(Similarity *sim, PostingList *plist, void *weight,
     CREATE(self, MatchPostingScorer, MATCHPOSTINGSCORER);
 
     /* assign */
-    REFCOUNT_INC(sim);
-    REFCOUNT_INC(plist);
-    self->sim           = sim;
-    self->plist         = plist;
+    self->sim           = REFCOUNT_INC(sim);
+    self->plist         = REFCOUNT_INC(plist);
     self->weight        = Native_new(weight);
     self->weight_value  = weight_value;
 
@@ -27,20 +25,17 @@ MatchPostScorer_new(Similarity *sim, PostingList *plist, void *weight,
     self->tally          = Tally_new();
     self->sprox          = NULL;
     self->score_cache    = NULL;
-
-    /* start off postings blob with dummy posting */
-    self->postings       = BB_new_str((char*)&POST_DUMMY, sizeof(Posting));
-    self->posting        = (Posting*)self->postings->ptr;
+    self->posting        = NULL;
 
     return self;
 }   
 
-
 MatchPostingScorer*
 MatchPost_make_scorer(MatchPosting *self, Similarity *sim, 
                       struct kino_PostingList *plist, 
                       void *weight, float weight_val)
 {
+    UNUSED_VAR(self);
     return MatchPostScorer_new(sim, plist, weight, weight_val);
 }
 
