@@ -19,7 +19,7 @@ struct kino_RichPostingScorer {
 kino_RichPostingScorer*
 kino_RichPostScorer_new(struct kino_Similarity *sim, 
                         struct kino_PostingList *plist, 
-                        void *weight_ref, float weight_value);
+                        void *weight, float weight_value);
 
 KINO_END_CLASS
 
