@@ -18,10 +18,8 @@ ScorePostScorer_new(Similarity *sim, PostingList *plist, void *weight,
     CREATE(self, ScorePostingScorer, SCOREPOSTINGSCORER);
 
     /* assign */
-    REFCOUNT_INC(sim);
-    REFCOUNT_INC(plist);
-    self->sim           = sim;
-    self->plist         = plist;
+    self->sim           = REFCOUNT_INC(sim);
+    self->plist         = REFCOUNT_INC(plist);
     self->weight        = Native_new(weight);
     self->weight_value  = weight_value;
 
@@ -29,10 +27,7 @@ ScorePostScorer_new(Similarity *sim, PostingList *plist, void *weight,
     self->sprox          = ScoreProx_new();
     self->tally          = Tally_new();
     Tally_Add_SProx(self->tally, self->sprox);
-
-    /* start off postings blob with dummy posting */
-    self->postings       = BB_new_str((char*)&POST_DUMMY, sizeof(Posting));
-    self->posting        = (Posting*)self->postings->ptr;
+    self->posting        = NULL;
 
     /* fill score cache */
     self->score_cache = MALLOCATE(TERMSCORER_SCORE_CACHE_SIZE, float);
