@@ -12,12 +12,9 @@ ANDORScorer_new(Similarity *sim, Scorer *and_scorer, Scorer *or_scorer)
     CREATE(self, ANDORScorer, ANDORSCORER);
 
     /* assign */
-    REFCOUNT_INC(sim);
-    REFCOUNT_INC(and_scorer);
-    REFCOUNT_INC(or_scorer);
-    self->sim              = sim;
-    self->and_scorer       = and_scorer;
-    self->or_scorer        = or_scorer;
+    self->sim              = REFCOUNT_INC(sim);
+    self->and_scorer       = REFCOUNT_INC(and_scorer);
+    self->or_scorer        = REFCOUNT_INC(or_scorer);
 
     /* init */
     self->or_scorer_first_time = true;
