@@ -28,8 +28,7 @@ ANDScorer_new(Similarity *sim)
     CREATE(self, ANDScorer, ANDSCORER);
 
     /* assign */
-    self->sim = sim;
-    REFCOUNT_INC(sim);
+    self->sim              = REFCOUNT_INC(sim);
 
     /* init */
     self->tally            = Tally_new();
@@ -69,8 +68,7 @@ ANDScorer_add_subscorer(ANDScorer *self, Scorer *subscorer)
         self->cap += 100;
         self->subscorers = REALLOCATE(self->subscorers, self->cap, Scorer*);
     }
-    REFCOUNT_INC(subscorer);
-    self->subscorers[ self->num_subs++ ] = subscorer;
+    self->subscorers[ self->num_subs++ ] = REFCOUNT_INC(subscorer);
 
     /* add to the matcher count; don't bother with subclauses */
     self->tally->num_matchers += 1;
