@@ -13,8 +13,7 @@ FieldDoc_new(u32_t doc_num, float score, FieldDocCollator *collator)
     /* assign */
     self->doc_num  = doc_num;
     self->score    = score;
-    REFCOUNT_INC(collator);
-    self->collator = collator;
+    self->collator = REFCOUNT_INC(collator);
 
     return self;
 }
