@@ -43,8 +43,7 @@ FDocCollator_add(FieldDocCollator *self, IntMap *sort_cache, bool_t rev)
         self->reversed = REALLOCATE(self->reversed, self->cap, bool_t);
     }
 
-    REFCOUNT_INC(sort_cache);
-    self->sort_caches[ self->size ] = sort_cache;
+    self->sort_caches[ self->size ] = REFCOUNT_INC(sort_cache);
     self->reversed[ self->size ]    = rev;
     self->size++;
 }
