@@ -92,8 +92,7 @@ HC_new_offset_coll(HitCollector *inner_coll, u32_t offset)
 {
     OffsCollData *data = MALLOCATE(1, OffsCollData);
     data->offset = offset;
-    data->inner_coll = inner_coll;
-    REFCOUNT_INC(inner_coll);
+    data->inner_coll = REFCOUNT_INC(inner_coll);
     return HC_new(HC_OffsColl_collect, HC_OffsColl_release, data);
 }
 
@@ -118,10 +117,8 @@ HitCollector*
 HC_new_filt_coll(HitCollector *inner_coll, BitVector *bit_vec)
 {
     FiltCollData *data = MALLOCATE(1, FiltCollData);
-    data->inner_coll = inner_coll;
-    data->bit_vec    = bit_vec;
-    REFCOUNT_INC(inner_coll);
-    REFCOUNT_INC(bit_vec);
+    data->inner_coll = REFCOUNT_INC(inner_coll);
+    data->bit_vec    = REFCOUNT_INC(bit_vec);
     return HC_new(HC_FiltColl_collect, HC_FiltColl_release, data);
 }
 
@@ -150,10 +147,8 @@ HC_new_range_coll(HitCollector *inner_coll, IntMap *sort_cache,
     RangeCollData *const data = MALLOCATE(1, RangeCollData);
 
     /* assign */
-    REFCOUNT_INC(sort_cache);
-    REFCOUNT_INC(inner_coll);
-    data->inner_coll  = inner_coll;
-    data->sort_cache  = sort_cache;
+    data->inner_coll  = REFCOUNT_INC(inner_coll);
+    data->sort_cache  = REFCOUNT_INC(sort_cache);
     data->lower_bound = lower_bound;
     data->upper_bound = upper_bound;
 
