@@ -15,10 +15,8 @@ MatchFieldScorer_new(Similarity *sim, IntMap *sort_cache, void *weight)
     CREATE(self, MatchFieldScorer, MATCHFIELDSCORER);
 
     /* assign */
-    REFCOUNT_INC(sim);
-    REFCOUNT_INC(sort_cache);
-    self->sim           = sim;
-    self->sort_cache    = sort_cache;
+    self->sim           = REFCOUNT_INC(sim);
+    self->sort_cache    = REFCOUNT_INC(sort_cache);
     self->weight        = Native_new(weight);
 
     /* init */
