@@ -27,8 +27,7 @@ SortColl_new(FieldDocCollator *collator, u32_t num_hits)
 
     /* assign */
     self->num_hits = num_hits;
-    REFCOUNT_INC(collator);
-    self->collator = collator;
+    self->collator = REFCOUNT_INC(collator);
 
     /* derive */
     self->hit_q       = (HitQueue*)SortedHitQ_new(num_hits);
