@@ -16,7 +16,7 @@ static ByteBuf*
 full_path(FSFolder *self, const ByteBuf *filename);
 
 static OutStream*
-do_open_outstream(FSFolder *self, const ByteBuf *filename, int oflags);
+do_open_outstream(FSFolder *self, const ByteBuf *filename);
 
 FSFolder*
 FSFolder_new(const ByteBuf *path) 
@@ -39,19 +39,19 @@ FSFolder_destroy(FSFolder *self)
 }
 
 #ifdef O_LARGEFILE
-static const int base_write_flags 
-    = O_CREAT | O_TRUNC | O_RDWR | O_NONBLOCK | O_LARGEFILE; 
-static const int base_read_flags = O_RDONLY | O_NONBLOCK | O_LARGEFILE; 
+static const int write_flags 
+    = O_CREAT | O_WRONLY | O_NONBLOCK | O_EXCL | O_LARGEFILE; 
+static const int read_flags = O_RDONLY | O_NONBLOCK | O_LARGEFILE; 
 #else
-static const int base_write_flags = O_CREAT | O_TRUNC | O_RDWR | O_NONBLOCK;
-static const int base_read_flags = O_RDONLY | O_NONBLOCK; 
+static const int write_flags 
+    = O_CREAT | O_WRONLY | O_NONBLOCK | O_EXCL;
+static const int read_flags = O_RDONLY | O_NONBLOCK; 
 #endif
 
 OutStream*
 FSFolder_open_outstream(FSFolder *self, const ByteBuf *filename)
 {
-    OutStream *outstream 
-        = do_open_outstream(self, filename, base_write_flags);
+    OutStream *outstream = do_open_outstream(self, filename);
     if (outstream == NULL) 
         CONFESS("Can't open '%s': %s", filename->ptr, strerror(errno));
     return outstream;
@@ -60,14 +60,14 @@ FSFolder_open_outstream(FSFolder *self, const ByteBuf *filename)
 OutStream*
 FSFolder_safe_open_outstream(FSFolder *self, const ByteBuf *filename)
 {
-    return do_open_outstream(self, filename, base_write_flags | O_EXCL);
+    return do_open_outstream(self, filename);
 }
 
 static OutStream*
-do_open_outstream(FSFolder *self, const ByteBuf *filename, int oflags)
+do_open_outstream(FSFolder *self, const ByteBuf *filename)
 {
     ByteBuf *path        = full_path(self, filename);
-    FSFileDes *file_des  = FSFileDes_new(path->ptr, oflags, 0600, "wb+");
+    FSFileDes *file_des  = FSFileDes_new(path->ptr, write_flags, 0600, "ab");
     OutStream *outstream = file_des == NULL
         ? NULL
         : OutStream_new((FileDes*)file_des);
@@ -85,7 +85,7 @@ FSFolder_open_instream(FSFolder *self, const ByteBuf *filename)
     InStream *instream = NULL;
     ByteBuf *path = full_path(self, filename);
     FSFileDes *file_des 
-        = FSFileDes_new(path->ptr, base_read_flags, 0600, "rb");
+        = FSFileDes_new(path->ptr, read_flags, 0600, "rb");
 
     REFCOUNT_DEC(path);
 
@@ -160,7 +160,7 @@ FSFolder_delete_file(FSFolder *self, const ByteBuf *filename)
     ByteBuf *path = full_path(self, filename);
     if ( remove(path->ptr) ) {
         REFCOUNT_DEC(path);
-        CONFESS("Couldn't remove file '%s': %s", path->ptr,
+        CONFESS("Couldn't remove file '%s': %s", filename->ptr,
             strerror(errno));
     }
     else {
@@ -178,7 +178,8 @@ FSFolder_slurp_file(FSFolder *self, const ByteBuf *filename)
     int amount_read;
 
     if (f == NULL) {
-        CONFESS("Couldn't open file '%s': %s", path->ptr, strerror(errno));
+        REFCOUNT_DEC(path);
+        CONFESS("Couldn't open file '%s': %s", filename->ptr, strerror(errno));
     }
 
     /* find length of file, allocate space */
@@ -193,7 +194,7 @@ FSFolder_slurp_file(FSFolder *self, const ByteBuf *filename)
         REFCOUNT_DEC(path);
         REFCOUNT_DEC(retval);
         CONFESS("Expected %d bytes reading %s, got %d", (int)len,
-            path->ptr, amount_read);
+            filename->ptr, amount_read);
     }
     retval->len = len;
 
@@ -201,7 +202,8 @@ FSFolder_slurp_file(FSFolder *self, const ByteBuf *filename)
     if (fclose(f)) {
         REFCOUNT_DEC(path);
         REFCOUNT_DEC(retval);
-        CONFESS("Couldn't fclose file '%s': %s", path->ptr, strerror(errno));
+        CONFESS("Couldn't fclose file '%s': %s", filename->ptr, 
+            strerror(errno));
     }
     REFCOUNT_DEC(path);
 
