@@ -12,42 +12,49 @@ struct kino_FileDes {
     KINO_FILEDES_VTABLE *_;
     KINO_OBJ_MEMBER_VARS;
     char       *path;
-    char       *mode;
-    kino_u64_t  pos;
-    kino_i32_t  stream_count;
+    chy_u64_t   pos;
+    chy_i32_t   stream_count;
 };
 
 /* Abstract method.  Seek FileDes to [target].
+ *
+ * @returns true on success, false on failure (sets kerror)
  */
-KINO_METHOD("Kino_FileDes_FDSeek",
-void
-kino_FileDes_fdseek(kino_FileDes *self, kino_u64_t target));
+chy_bool_t
+kino_FileDes_fdseek(kino_FileDes *self, chy_u64_t target);
+KINO_METHOD("Kino_FileDes_FDSeek");
 
 /* Abstract method.  Read [len] bytes into [dest], starting after
  * [dest_offset] bytes.
+ *
+ * @returns true on success, false on failure (sets kerror)
  */
-KINO_METHOD("Kino_FileDes_FDRead",
-void
-kino_FileDes_fdread(kino_FileDes *self, char *dest, kino_u32_t dest_offset, 
-                    kino_u32_t len));
+chy_bool_t
+kino_FileDes_fdread(kino_FileDes *self, char *dest, chy_u32_t dest_offset, 
+                    chy_u32_t len);
+KINO_METHOD("Kino_FileDes_FDRead");
 
 /* Abstract method.  Write buffer to target.
+ *
+ * @returns true on success, false on failure (sets kerror)
  */
-KINO_METHOD("Kino_FileDes_FDWrite",
-void
-kino_FileDes_fdwrite(kino_FileDes *self, char* buf, kino_u32_t len));
+chy_bool_t
+kino_FileDes_fdwrite(kino_FileDes *self, const char* buf, chy_u32_t len);
+KINO_METHOD("Kino_FileDes_FDWrite");
 
 /* Abstract method.  Return the current length of the file in bytes.
  */
-KINO_METHOD("Kino_FileDes_FDLength",
-kino_u64_t 
-kino_FileDes_fdlength(kino_FileDes *self));
+chy_u64_t 
+kino_FileDes_fdlength(kino_FileDes *self);
+KINO_METHOD("Kino_FileDes_FDLength");
 
 /* Abstract method. Close the stream, releasing resources.
+ *
+ * @returns true on success, false on failure (sets kerror)
  */
-KINO_METHOD("Kino_FileDes_FDClose",
-void
-kino_FileDes_fdclose(kino_FileDes *self));
+chy_bool_t
+kino_FileDes_fdclose(kino_FileDes *self);
+KINO_METHOD("Kino_FileDes_FDClose");
 
 KINO_END_CLASS
 
@@ -56,14 +63,20 @@ KINO_END_CLASS
  * they're the canary in the coal mine for detecting object-destruction memory
  * leaks.
  */
-extern kino_i32_t kino_FileDes_global_count; 
+extern chy_i32_t kino_FileDes_object_count; 
+
+/* Similar to above, but incremented upon successful open and decremented on
+ * successful close
+ */
+extern chy_i32_t kino_FileDes_open_count; 
 
 /* Size of the memory buffer used by both InStream and OutStream.
  */
 #define KINO_IO_STREAM_BUF_SIZE 1024
 
 #ifdef KINO_USE_SHORT_NAMES
-  #define FileDes_global_count        kino_FileDes_global_count
+  #define FileDes_object_count        kino_FileDes_object_count
+  #define FileDes_open_count          kino_FileDes_open_count
   #define IO_STREAM_BUF_SIZE          KINO_IO_STREAM_BUF_SIZE
 #endif
 
