@@ -32,8 +32,7 @@ Lock_new(Folder *folder, const ByteBuf *lock_name, const ByteBuf *agent_id,
     CREATE(self, Lock, LOCK);
 
     /* assign */
-    REFCOUNT_INC(folder);
-    self->folder       = folder;
+    self->folder       = REFCOUNT_INC(folder);
     self->timeout      = timeout;
     self->lock_name    = BB_CLONE(lock_name);
     self->agent_id     = BB_CLONE(agent_id);
