@@ -17,8 +17,7 @@ LockFact_new(Folder *folder, const ByteBuf *agent_id)
     CREATE(self, LockFactory, LOCKFACTORY);
 
     /* assign */
-    REFCOUNT_INC(folder);
-    self->folder       = folder;
+    self->folder       = REFCOUNT_INC(folder);
     self->agent_id     = BB_CLONE(agent_id);
 
     return self;
