@@ -36,10 +36,12 @@ sub build {
     find(
         {   wanted => sub {
                 if ( $File::Find::name =~ /\.h$/ ) {
-                    push @all_h_paths, $File::Find::name;
+                    push @all_h_paths, $File::Find::name
+                        unless /#/;    # skip emacs .#filename.h lock files
                 }
             },
             no_chdir => 1,
+            follow   => 1,    # follow symlinks if possible (noop on Windows)
         },
         $self->{base_dir},
     );
@@ -88,6 +90,12 @@ sub build {
     while ( my ( $nickname, $class ) = each %classes ) {
         my $parent_name = $class->get_parent_class_name;
         next if $parent_name eq '';    # skip Obj, which has no parent
+        if ( not exists $classes{$parent_name} ) {
+            confess(  "parent class '$parent_name' not defined "
+                    . "for class '"
+                    . $class->get_class_name
+                    . "'" );
+        }
         $classes{$parent_name}->add_child($class);
     }
 
