@@ -5,7 +5,7 @@ package KinoSearch;
 
 use 5.008003;
 
-our $VERSION = '0.20_04';
+our $VERSION = '0.20_05';
 
 use constant K_DEBUG => 0;
 
@@ -48,7 +48,7 @@ KinoSearch - Search engine library.
 
 =head1 VERSION
 
-0.20_04
+0.20_05
 
 =head1 EXTRA WARNING
 
@@ -76,8 +76,8 @@ First, plan out your index structure and describe it with a "schema".
     use KinoSearch::Analysis::PolyAnalyzer;
     
     our %fields = (
-        title   => 'KinoSearch::Schema::FieldSpec',
-        content => 'KinoSearch::Schema::FieldSpec',
+        title   => 'text',
+        content => 'text',
     );
 
     sub analyzer { 
@@ -144,8 +144,8 @@ UTF-8 support.
 
 =item *
 
-Support for boolean operators AND, OR, and AND NOT; parenthetical groupings,
-and prepended +plus and -minus
+Support for boolean operators AND, OR, and AND NOT; parenthetical groupings;
+and prepended +plus and -minus.
 
 =item *
 
@@ -193,7 +193,7 @@ L<KinoSearch::Schema> - Plan out your index.
 
 =item *
 
-L<KinoSearch::Schema::FieldSpec> - Define index fields.
+L<KinoSearch::FieldSpec> - Define index fields.
 
 =item *
 
