@@ -9,8 +9,8 @@ our %instance_vars = (
     # members
     default_encoder   => undef,
     default_formatter => undef,
-    specs             => [],
-    terms             => [],
+    specs             => undef,
+    terms             => undef,
     limit             => undef,
     token_re          => qr/\b\w+(?:'\w+)?\b/,
 );
@@ -22,6 +22,8 @@ use KinoSearch::Highlight::SimpleHTMLEncoder;
 
 sub init_instance {
     my $self = shift;
+    $self->{specs} = [];
+    $self->{terms} = [];
 
     # create shared default encoder and formatter
     $self->{default_encoder} = KinoSearch::Highlight::SimpleHTMLEncoder->new;
@@ -389,7 +391,7 @@ Add a spec for a single highlighted excerpt.  Takes hash-style parameters:
 
 B<field> - the name of the field from which to draw the excerpt.  The field
 must be C<vectorized> (which is the default -- see
-L<FieldSpec|KinoSearch::Schema::FieldSpec>).
+L<FieldSpec|KinoSearch::FieldSpec>).
 
 =item *
 
