@@ -12,8 +12,8 @@ our %instance_vars = (
     lock_factory => undef,
 
     # members
-    sort_caches => {},
-    lex_caches  => {},
+    sort_caches => undef,
+    lex_caches  => undef,
     read_lock   => undef,
     commit_lock => undef,
 );
