@@ -12,17 +12,17 @@ our %instance_vars = (
     lock_factory => undef,
 
     # params / members
-    sub_readers => [],
+    sub_readers => undef,
 
     # inherited members
-    sort_caches => {},
-    lex_caches  => {},
+    sort_caches => undef,
+    lex_caches  => undef,
     read_lock   => undef,
     commit_lock => undef,
 
     # members
     max_doc => 0,
-    starts  => [],
+    starts  => undef,
 );
 
 use KinoSearch::Index::SegReader;
@@ -38,6 +38,10 @@ use KinoSearch::Util::Int;
 
 sub init_instance {
     my $self = shift;
+    $self->{sub_readers} ||= [];
+    $self->{starts}      = [];
+    $self->{sort_caches} = {};
+    $self->{lex_caches}  = {};
 
     $self->_init_sub_readers;
 }
