@@ -70,34 +70,6 @@ CODE:
     RETVAL = Kino_PList_Get_Doc_Freq(self);
 OUTPUT: RETVAL
 
-chy_u32_t
-bulk_read(self, postings_av, num_wanted)
-    kino_PostingList *self;
-    AV *postings_av;
-    chy_u32_t num_wanted;
-CODE:
-{
-    kino_Posting *temp;
-    kino_ByteBuf *postings = kino_BB_new(1200);
-
-    /* read into ByteBuf */
-    RETVAL = Kino_PList_Bulk_Read(self, postings, num_wanted);
-
-    /* make legit copies */
-    av_clear(postings_av);
-    temp = (kino_Posting*)postings->ptr;
-    temp = temp->next; /* advance past dummy */
-    while (temp != NULL) {
-        kino_Posting *evil_twin = (kino_Posting*)Kino_Post_Clone(temp);
-        SV *evil_twin_sv = kobj_to_pobj(evil_twin);
-        av_push(postings_av, evil_twin_sv);
-        REFCOUNT_DEC(evil_twin);
-        temp = temp->next;
-    }
-    REFCOUNT_DEC(postings);
-}
-OUTPUT: RETVAL
-
 kino_Scorer*
 make_scorer(self, ...)
     kino_PostingList *self;
