@@ -12,16 +12,16 @@ our %instance_vars = (
     schema => undef,
 
     # members
-    infos       => {},
+    infos       => undef,
     seg_counter => 0,
-    version     => ( int( time * 1000 ) ),
+    version     => undef,
     generation  => 0,
 );
 
 BEGIN { __PACKAGE__->ready_get_set(qw( seg_counter generation )) }
 
 use KinoSearch::Index::SegInfo;
-use KinoSearch::Schema::FieldSpec;
+use KinoSearch::FieldSpec;
 use KinoSearch::Schema;
 use KinoSearch::Index::IndexFileNames
     qw( filename_from_gen SEG_INFOS_FORMAT );
@@ -32,6 +32,8 @@ sub init_instance {
     my $self = shift;
     confess("Missing required parameter schema")
         unless defined $self->{schema};
+    $self->{infos}   = {};
+    $self->{version} = int( time * 1000 );
 }
 
 # Add a SegInfo to the collection.
@@ -103,10 +105,10 @@ sub read_infos {
     # Add any unknown fields to the Schema instance
     $segs_data->{fields} ||= {};
     while ( my ( $field, $fspec_class ) = each %{ $segs_data->{fields} } ) {
-        if ( !$fspec_class->isa("KinoSearch::Schema::FieldSpec") ) {
+        if ( !$fspec_class->isa("KinoSearch::FieldSpec") ) {
             confess(  "Attempted to load field '$field' assigned to "
                     . "'$fspec_class', but '$fspec_class' isn't a "
-                    . "KinoSearch::Schema::FieldSpec" );
+                    . "KinoSearch::FieldSpec" );
         }
         $schema->add_field( $field, $fspec_class );
     }
