@@ -15,8 +15,8 @@ our %instance_vars = (
     seg_info => undef,
 
     # inherited members
-    sort_caches => {},
-    lex_caches  => {},
+    sort_caches => undef,
+    lex_caches  => undef,
     read_lock   => undef,
     commit_lock => undef,
 
@@ -65,6 +65,8 @@ use KinoSearch::Util::Int;
 sub init_instance {
     my $self = shift;
     my ( $invindex, $seg_info ) = @{$self}{qw( invindex seg_info )};
+    $self->{sort_caches} = {};
+    $self->{lex_caches}  = {};
 
     # extract schema
     my $schema = $self->{schema} = $invindex->get_schema;
