@@ -8,6 +8,7 @@ use base qw( KinoSearch::Util::Obj );
 use KinoSearch::InvIndex;
 use KinoSearch::Search::Similarity;
 use KinoSearch::Util::Hash;
+use KinoSearch::FieldSpec;
 use KinoSearch::Schema::FieldSpec;
 
 #-----------------------------------------------------------------------
@@ -83,6 +84,8 @@ my %reserved_names = (
     excerpts  => 1,
 );
 
+my %aliases = ( text => 'KinoSearch::FieldSpec::text', );
+
 sub add_field {
     my ( $self, $field_name, $fspec_class ) = @_;
 
@@ -94,15 +97,29 @@ sub add_field {
     confess("Field names beginning with 'kino' are reserved")
         if $field_name =~ /^kino/i;
 
-    if ( !$fspec_class->isa('KinoSearch::Schema::FieldSpec') ) {
+    # grok aliases
+    if ( $fspec_class =~ /^[a-z:]+$/ ) {
+        my $class = $aliases{$fspec_class};
+        confess(  "All-lower-case names are reserved, but "
+                . "'$fspec_class' isn't recognized" )
+            unless $class;
+        eval "require $class";
+        $fspec_class = $class;
+    }
+
+    confess("Field names beginning with 'kino' are reserved")
+        if $field_name =~ /^kino/i;
+
+    if ( !$fspec_class->isa('KinoSearch::FieldSpec') ) {
         confess(  "'$fspec_class' either isn't loaded or isn't a "
-                . "KinoSearch::Schema::FieldSpec" );
+                . "KinoSearch::FieldSpec" );
     }
 
     # if the field already has an association, verify pairing and return
     my $current = $self->fetch_fspec($field_name);
     if ($current) {
-        return if $fspec_class eq ref($current);
+        return if $fspec_class           eq ref($current);
+        return if $aliases{$fspec_class} eq ref($current);
         confess(  "'$field_name' assigned to '$fspec_class', "
                 . "which conflicts with '$current'" );
     }
@@ -309,8 +326,8 @@ of your inverted index.
     use KinoSearch::Analysis::PolyAnalyzer;
 
     our %fields = (
-        title   => 'KinoSearch::Schema::FieldSpec',
-        content => 'KinoSearch::Schema::FieldSpec',
+        title   => 'text',
+        content => 'text',
     );
 
     sub analyzer { 
@@ -363,19 +380,30 @@ during subsequent indexing sessions.
 =head2 %fields
 
 Every Schema subclass must declare a C<%fields> hash using C<our> (I<not>
-C<my>).  Each key in the hash is a field name, and each value must be a class
-name identifying a class which isa L<KinoSearch::Schema::FieldSpec>.
+C<my>).  Each key in the hash is a field name, and each value must be either
+
+=over
+
+=item 1 a natively supported type, or
+
+=item 2 a class name identifying a class which isa L<KinoSearch::FieldSpec>.
+
+=back
+
+At present, there is only one natively supported type: C<text>.  The FieldSpec
+subclass which determines its behavior is L<KinoSearch::FieldSpec::text>.
+However, all lower-case-only names are reserved.
 
     package UnAnalyzedField;
-    use base qw( KinoSearch::Schema::FieldSpec );
+    use base qw( KinoSearch::FieldSpec::text );
     sub analyzed { 0 }
 
     package MySchema;
     use base qw( KinoSearch::Schema );
 
     our %fields = (
-        title   => 'KinoSearch::Schema::FieldSpec',
-        content => 'KinoSearch::Schema::FieldSpec',
+        title   => 'text',
+        content => 'text',
         url     => 'UnAnalyzedField',
     );
 
@@ -475,13 +503,13 @@ loaded/verified via add_field().
 
 =head2 add_field
 
-    $schema->add_field( foo => 'KinoSearch::Analysis::FieldSpec' );
+    $schema->add_field( foo => 'text' );
 
 Add a field to an individual schema object.  
 
 Calling add_field multiple times against the same field name is fine, but the
-name of the FieldSpec subclass must always be the same or an exception will be
-thrown.
+name of the supported field type or FieldSpec subclass must always be the same
+or an exception will be thrown.
 
 =head1 COPYRIGHT
 
