@@ -10,7 +10,7 @@ our %instance_vars = (
     boost => 1.0,
 
     # members
-    clauses          => [],
+    clauses          => undef,
     max_clause_count => 1024,
 );
 
@@ -20,6 +20,11 @@ BEGIN {
 
 use KinoSearch::Search::BooleanClause;
 
+sub init_instance {
+    my $self = shift;
+    $self->{clauses} = [];
+}
+
 # Add an subquery tagged with boolean characteristics.
 sub add_clause {
     my $self = shift;
@@ -63,7 +68,7 @@ our %instance_vars = (
     similarity => undef,
 
     # members
-    sub_weights => [],
+    sub_weights => undef,
 );
 
 use KinoSearch::Search::BooleanScorer;
@@ -78,6 +83,7 @@ sub init_instance {
     $self->{similarity} = $searcher->get_schema->fetch_sim;
 
     # iterate over the clauses, creating a Weight for each one
+    $self->{sub_weights} = [];
     for my $clause ( @{ $self->{parent}{clauses} } ) {
         my $sub_query = $clause->get_query;
         push @{ $self->{sub_weights} }, $sub_query->make_weight($searcher);
