@@ -8,22 +8,22 @@ use base qw( KinoSearch::Util::Obj );
 sub new { confess("Not accessible from Perl-space") }
 
 our %new_offs_coll_defaults = (
-    hit_collector => undef,
-    offset        => undef,
+    collector => undef,
+    offset    => undef,
 );
 
 our %new_bit_coll_defaults = ( bit_vector => undef, );
 
 our %new_filt_coll_defaults = (
-    hit_collector => undef,
-    filter_bits   => undef,
+    collector   => undef,
+    filter_bits => undef,
 );
 
 our %new_range_coll_defaults = (
-    hit_collector => undef,
-    sort_cache    => undef,
-    lower_bound   => undef,
-    upper_bound   => undef,
+    collector   => undef,
+    sort_cache  => undef,
+    lower_bound => undef,
+    upper_bound => undef,
 );
 
 1;
@@ -42,8 +42,8 @@ CODE:
     HV *const args_hash = build_args_hash( &(ST(0)), 1, items,
         "KinoSearch::Search::HitCollector::new_offs_coll_defaults");
     kino_HitCollector *inner_coll = (kino_HitCollector*)extract_obj(
-        args_hash, SNL("hit_collector"), "KinoSearch::Search::HitCollector");
-    kino_u32_t offset = extract_uv(args_hash, SNL("offset"));
+        args_hash, SNL("collector"), "KinoSearch::Search::HitCollector");
+    chy_u32_t offset = extract_uv(args_hash, SNL("offset"));
 
     /* create object */
     RETVAL = kino_HC_new_offset_coll(inner_coll, offset);
@@ -73,7 +73,7 @@ CODE:
     HV *const args_hash = build_args_hash( &(ST(0)), 1, items,
         "KinoSearch::Search::HitCollector::new_filt_coll_defaults");
     kino_HitCollector *inner_coll = (kino_HitCollector*)extract_obj(
-        args_hash, SNL("hit_collector"), "KinoSearch::Search::HitCollector");
+        args_hash, SNL("collector"), "KinoSearch::Search::HitCollector");
     kino_BitVector *filt_bits = (kino_BitVector*)extract_obj(
         args_hash, SNL("filter_bits"), "KinoSearch::Util::BitVector");
 
@@ -90,11 +90,11 @@ CODE:
     HV *const args_hash = build_args_hash( &(ST(0)), 1, items,
         "KinoSearch::Search::HitCollector::new_range_coll_defaults");
     kino_HitCollector *inner_coll = (kino_HitCollector*)extract_obj(
-        args_hash, SNL("hit_collector"), "KinoSearch::Search::HitCollector");
+        args_hash, SNL("collector"), "KinoSearch::Search::HitCollector");
     kino_IntMap *sort_cache = (kino_IntMap*)extract_obj(
         args_hash, SNL("sort_cache"), "KinoSearch::Util::IntMap");
-    kino_i32_t lower_bound = extract_iv(args_hash, SNL("lower_bound"));
-    kino_i32_t upper_bound = extract_iv(args_hash, SNL("upper_bound"));
+    chy_i32_t lower_bound = extract_iv(args_hash, SNL("lower_bound"));
+    chy_i32_t upper_bound = extract_iv(args_hash, SNL("upper_bound"));
 
     /* create object */
     RETVAL = kino_HC_new_range_coll(inner_coll, sort_cache, lower_bound,
@@ -105,7 +105,7 @@ OUTPUT: RETVAL
 void
 collect(self, doc_num, score)
     kino_HitCollector *self;
-    kino_u32_t    doc_num;
+    chy_u32_t     doc_num;
     float         score;
 PPCODE:
     self->collect(self, doc_num, score);
@@ -127,7 +127,7 @@ with them, based on the collector->collect method.
 
 =head2 collect
 
-    $hit_collector->collect( $doc_num, $score );
+    $collector->collect( $doc_num, $score );
 
 Abstract method.
 
