@@ -6,75 +6,48 @@ use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class );
 
 our %instance_vars = (
-    # params/members
-    searcher  => undef,
-    query     => undef,
-    filter    => undef,
-    sort_spec => undef,
+    # required params
+    query    => undef,
+    searcher => undef,
+    top_docs => undef,
 
-    # members
+    # params/members
+    offset      => 0,
     highlighter => undef,
-    score_docs  => undef,
-    total_hits  => undef,
-    tick        => undef,
 );
 
-BEGIN { __PACKAGE__->ready_get(qw( score_docs )) }
+BEGIN { __PACKAGE__->ready_get_set(qw( offset )) }
 
-use KinoSearch::Highlight::Highlighter;
+sub init_instance {
+    my $self = shift;
 
-sub seek {
-    my ( $self, $offset, $num_wanted ) = @_;
-    my $searcher = $self->{searcher};
-
-    confess('Usage: $hits->seek( OFFSET, NUM_WANTED );')
-        unless @_ = 3;
-
-    # set our pointer for the next call to fetch_hit_hashref
-    $self->{tick} = $offset;
-
-    # if the seek takes us within bounds, don't redo the search
-    if ( defined $self->{score_docs}
-        and @{ $self->{score_docs} } > $offset + $num_wanted )
-    {
-        return;
-    }
-
-    # collect enough to satisfy both the offset and the num wanted
-    my $top_docs = $searcher->top_docs(
-        num_wanted => $num_wanted + $offset,
-        query      => $self->{query},
-        filter     => $self->{filter},
-        sort_spec  => $self->{sort_spec},
-    );
-
-    # store away score_docs and total_hits
-    $self->{score_docs} = $top_docs->get_score_docs;
-    $self->{total_hits} = $top_docs->get_total_hits;
+    confess "top_docs is mandatory" unless $self->{top_docs};
+    confess "query is mandatory"    unless $self->{query};
+    confess "searcher is mandatory" unless $self->{searcher};
 }
 
 sub total_hits {
     my $self = shift;
-    confess("seek() must be called before total_hits()")
-        unless defined $self->{total_hits};
-    return $self->{total_hits};
+    return $self->{top_docs}->get_total_hits;
+}
+
+sub get_score_docs {
+    my $self = shift;
+    return $self->{top_docs}->get_score_docs;
 }
 
 sub fetch_hit_hashref {
-    my $self     = shift;
-    my $searcher = $self->{searcher};
+    my ($self) = @_;
 
-    confess("seek() must be called before total_hits()")
-        unless defined $self->{total_hits};
+    # get a score doc then increment counter for next time
+    my $score_doc = $self->get_score_docs->[ $self->{offset}++ ];
 
     # bail if there aren't any more *captured* hits
-    return if ( $self->{tick} >= @{ $self->{score_docs} } );
-
-    # get a score doc then increment counter
-    my $score_doc = $self->{score_docs}[ $self->{tick}++ ];
+    return unless $score_doc;
 
     # lazily fetch stored fields
-    my $hashref = $searcher->fetch_doc( $score_doc->get_doc_num );
+    my $searcher = $self->{searcher};
+    my $hashref  = $searcher->fetch_doc( $score_doc->get_doc_num );
 
     # add score to hashref
     $hashref->{score} = $score_doc->get_score;
@@ -119,27 +92,17 @@ KinoSearch::Search::Hits - Access search results.
 
 =head1 DESCRIPTION
 
-Hits objects are iterators used to access the results of a search.  
-
-A classic application would be paging through hits.  After the first 10 hits
-are displayed, if the user wants to see more -- and there are more than 10
-total hits -- the Hits object may seek() to an OFFSET of 10 and retrieve 10
-more documents.  And so on.
+Hits objects are iterators used to access the results of a search.
 
 =head1 METHODS
 
-=head2 seek 
-
-    $hits->seek( OFFSET, NUM_WANTED );
-
-Position the Hits iterator at C<OFFSET> and capture C<NUM_WANTED> docs.
-
 =head2 total_hits
 
     my $num_that_matched = $hits->total_hits;
 
 Return the total number of documents which matched the query used to produce
-the Hits object.  (This number is unlikely to match C<NUM_WANTED>.)
+the Hits object.  Note that this is the total number of matches, not just the
+number collected, and thus will rarely match C<NUM_WANTED>.
 
 =head2 fetch_hit_hashref
 
@@ -169,4 +132,3 @@ Copyright 2005-2007 Marvin Humphrey
 See L<KinoSearch> version 0.20.
 
 =cut
-
