@@ -14,8 +14,8 @@ our %instance_vars = (
 
     # members
     field     => undef,
-    terms     => [],
-    positions => [],
+    terms     => undef,
+    positions => undef,
 );
 
 BEGIN {
@@ -28,6 +28,12 @@ use KinoSearch::Util::ToStringUtils qw( boost_to_string );
 use KinoSearch::Util::VArray;
 use KinoSearch::Util::Int;
 
+sub init_instance {
+    my $self = shift;
+    $self->{terms}     = [];
+    $self->{positions} = [];
+}
+
 # Add a term/position combo to the query.  The position is specified
 # explicitly in order to allow for phrases with gaps, two terms at the same
 # position, etc.
