@@ -7,7 +7,7 @@ use base qw( KinoSearch::Search::Filter );
 
 our %instance_vars = (
     # inherited
-    cached_bits => {},
+    cached_bits => undef,
 
     # constructor params / members
     query => undef,
@@ -20,6 +20,7 @@ sub init_instance {
     my $self = shift;
     confess("required parameter query is not a KinoSearch::Search::Query")
         unless a_isa_b( $self->{query}, 'KinoSearch::Search::Query' );
+    $self->{cached_bits} = {};
 }
 
 sub bits {
