@@ -23,7 +23,7 @@ our %search_args = (
     num_wanted => 10,
 );
 
-# Returns a Hits object which calls top_docs().
+# Returns a Hits object containing the top scoring results
 sub search {
     my $self = shift;
     confess kerror() unless verify_args( \%search_args, @_ );
@@ -34,15 +34,21 @@ sub search {
         $args{query} = $self->_prepare_simple_search( $args{query} );
     }
 
-    # get a Hits object, and perform the search
-    my $hits = KinoSearch::Search::Hits->new(
-        searcher  => $self,
-        query     => $args{query},
-        filter    => $args{filter},
-        sort_spec => $args{sort_spec},
+    # run the search and collect the top matches
+    my $top_docs = $self->top_docs(
+        num_wanted => $args{num_wanted} + $args{offset},
+        query      => $args{query},
+        filter     => $args{filter},
+        sort_spec  => $args{sort_spec},
+    );
+
+    # create an object that contains those results
+    return KinoSearch::Search::Hits->new(
+        searcher => $self,
+        query    => $args{query},
+        top_docs => $top_docs,
+        offset   => $args{offset},
     );
-    $hits->seek( $args{offset}, $args{num_wanted} );
-    return $hits;
 }
 
 # Search for the query string against all indexed fields
