@@ -127,7 +127,7 @@ PPCODE:
     }
     free(array_copy);
 
-    XPUSHs(newRV_noinc( (SV*)out_av ));
+    XPUSHs( sv_2mortal(newRV_noinc( (SV*)out_av )) );
     XSRETURN(1);
 }
 
