@@ -28,6 +28,15 @@ CODE:
 }
 OUTPUT: RETVAL
 
+kino_ByteBuf*
+deserialize(either_sv, serialized)
+    SV *either_sv;
+    kino_ViewByteBuf serialized;
+CODE:
+    CHY_UNUSED_VAR(either_sv);
+    RETVAL = kino_BB_deserialize(&serialized);
+OUTPUT: RETVAL
+
 chy_bool_t
 starts_with(self, prefix)
     kino_ByteBuf *self;
