@@ -6,8 +6,6 @@ use KinoSearch::Util::ToolSet;
 
 our %instance_vars = ();
 
-use Clone 'clone';
-
 sub new {
     my $class = shift;    # leave the rest of @_ intact.
 
@@ -25,12 +23,8 @@ sub new {
         confess kerror() unless verify_args( $defaults, @_ );
     }
 
-    # merge var => val pairs into new object
-    my $self = clone($defaults);
-    bless $self, $class;
-    %$self = ( %$self, @_ );
-
-    # call customizable initialization routine
+    # merge var => val pairs into new object, call customizable init routine
+    my $self = bless { %$defaults, @_ }, $class;
     $self->init_instance;
 
     return $self;
@@ -134,10 +128,10 @@ warning.  Do not use it on its own.
     our %instance_vars = (
         # constructor params / members
         foo => undef,
-        bar => {},
+        bar => 10,
 
         # members
-        baz => {},
+        baz => '',
     );
 
 =head1 DESCRIPTION
@@ -172,14 +166,14 @@ for the creation of a hash-based object.
     our %instance_vars = (
         # constructor params / members
         foo => undef,
-        bar => {},
+        bar => 10,
 
         # members
         baz => '',
     );
 
-%instance_vars may contain hashrefs and array-refs, as L<Clone>'s
-C<clone()> method is used to produce a deep copy.
+%instance_vars may only contain scalar values, as the defaults are merged
+into the object using a shallow copy.
 
 =head1 METHODS
 
@@ -189,9 +183,9 @@ A generic constructor with basic argument checking.  new() expects hash-style
 labeled parameters; the label names must be present in the %instance_vars
 hash, or it will confess().
 
-After verifying the labeled parameters, new() creates a deep clone of
-%instance_vars, and merges in the labeled arguments.  It then calls
-$self->init_instance() before returning the blessed reference.
+After verifying the labeled parameters, new() merges %instance_vars and @_
+into a new object.  It then calls $self->init_instance() before returning the
+blessed reference.
 
 =head2 init_instance
 
