@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package USConSchema::UnIndexedField;
-use base 'KinoSearch::Schema::FieldSpec';
+use base 'KinoSearch::FieldSpec::text';
 sub indexed {0}
 
 package USConSchema;
@@ -10,8 +10,8 @@ use base 'KinoSearch::Schema';
 use KinoSearch::Analysis::PolyAnalyzer;
 
 our %fields = (
-    title   => 'KinoSearch::Schema::FieldSpec',
-    content => 'KinoSearch::Schema::FieldSpec',
+    title   => 'text',
+    content => 'text',
     url     => 'USConSchema::UnIndexedField',
 );
 
